@@ -1,4 +1,4 @@
-__version__ = "0.6.0"  # noqa
+__version__ = "0.7.0"  # noqa
 
 from .stats import (  # noqa
     uniform_pdf,
@@ -9,6 +9,8 @@ from .stats import (  # noqa
     norm_ppf,
     poisson_pmf,
     poisson_cdf,
+    cpoisson_pmf,
+    cpoisson_cdf,
     expon_pdf,
     expon_cdf,
     expon_ppf,
@@ -18,16 +20,21 @@ from .stats import (  # noqa
     voigt_pdf,
     tsallis_pdf,
     tsallis_cdf,
+    crystalball_pdf,
+    crystalball_cdf,
 )
 
 from argparse import Namespace
 
+# TODO this does not work in numba
 uniform = Namespace(pdf=uniform_pdf, cdf=uniform_cdf, ppf=uniform_ppf)
 norm = Namespace(pdf=norm_pdf, cdf=norm_cdf, ppf=norm_ppf)
 poisson = Namespace(pmf=poisson_pmf, cdf=poisson_cdf)
+cpoisson = Namespace(pmf=cpoisson_pmf, cdf=cpoisson_cdf)
 expon = Namespace(pdf=expon_pdf, cdf=expon_cdf, ppf=expon_ppf)
 t = Namespace(pdf=t_pdf, cdf=t_cdf, ppf=t_ppf)
 voigt = Namespace(pdf=voigt_pdf)
 tsallis = Namespace(pdf=tsallis_pdf, cdf=tsallis_cdf)
+crystalball = Namespace(pdf=crystalball_pdf, cdf=crystalball_cdf)
 
 del Namespace
